@@ -22,6 +22,8 @@ function(sgp_object,
 	simulate.sgps=TRUE,
 	calculate.simex=NULL,
 	calculate.simex.baseline=NULL,
+	calculate.srs=NULL,
+	calculate.srs.baseline=NULL,
 	goodness.of.fit.print=TRUE,
 	parallel.config=NULL,
 	save.intermediate.results=FALSE,
@@ -122,6 +124,8 @@ function(sgp_object,
 			simulate.sgps=simulate.sgps,
 			calculate.simex=calculate.simex,
 			calculate.simex.baseline=calculate.simex.baseline,
+			calculate.srs=calculate.srs,
+			calculate.srs.baseline=calculate.srs.baseline,
 			goodness.of.fit.print=goodness.of.fit.print,
 			parallel.config=parallel.config,
 			verbose.output=verbose.output,
