@@ -280,6 +280,13 @@ if (bubble_plot_configs.BUBBLE_PLOT_DEVICE == "PNG") {
 	Cairo(file=gsub(".pdf", ".png", file.path.and.name), width=fig.width, height=8.5, bg=format.colors.background, units="in", dpi=144, pointsize=10.5)
 }
 
+if (bubble_plot_configs.BUBBLE_PLOT_DEVICE == "SVG") {
+    svglite(filename = gsub(".pdf", ".svg", file.path.and.name),
+            width = fig.width, height = 8.5, pointsize = 11,
+            bg = format.colors.background
+    )
+}
+
 # Create plot (if bubble_plot_configs.BUBBLE_TIPS==TRUE)
 
 if (bubble_plot_configs.BUBBLE_TIPS) {
@@ -715,7 +722,7 @@ popViewport()
 
 # Turn off device
 
-if (bubble_plot_configs.BUBBLE_PLOT_DEVICE %in% c("PDF", "PNG")) {
+if (bubble_plot_configs.BUBBLE_PLOT_DEVICE %in% c("PDF", "PNG", "SVG")) {
     dev.off()
 }
 
