@@ -630,18 +630,25 @@
 			# Write tmp.simulation.dt to disk for SNOW backends in Windows (& SNOT_TEST) Only
 			tmp.simulation.dt <- "sqlite"
 			dbWriteTable(sgp_data_for_summary, name = "sim_data", overwrite = TRUE, row.names=FALSE,
-				value = combineSims(sgp_object)[, SIM_NUM := 1:sim.info[['n.simulated.sgps']]])
+				value = combineSims(sgp_object)[,
+				  SIM_NUM := rep(1:sim.info[["n.simulated.sgps"]], sim.info[["n.unique.cases"]])
+				]
+			)
 		} else {
 			tmp.simulation.dt <- combineSims(sgp_object)
 		}
 	} else tmp.simulation.dt <- sim.info <- NULL
 
-	dbDisconnect(sgp_data_for_summary)
-
-	if (!is.null(parallel.config))	par.start <- startParallel(parallel.config, 'SUMMARY') else par.start <- list(par.type="NONE")
-
-	# Don't use SNOW - run as FOREACH + doParallel instead.
-	if (identical(par.start[['par.type']], "SNOW")) {parallel.config[["BACKEND"]] <- "FOREACH"; parallel.config[["TYPE"]] <- "doParallel"}
+	# Use FOREACH + doParallel exclusively for Windows/SNOW
+	if ((!identical(.Platform$OS.type, "unix") & !is.null(parallel.config)) | !is.null(parallel.config[["SNOW_TEST"]])) {
+		parallel.config[["BACKEND"]] <- "FOREACH"
+		parallel.config[["TYPE"]] <- "doParallel"
+	}
+	if (!is.null(parallel.config)) {
+		par.start <- startParallel(parallel.config, 'SUMMARY')
+	} else {
+		par.start <- list(par.type="NONE")
+	}
 
 	for (j in seq(length(summary.groups[["institution_multiple_membership"]])+1)) {
 		for (i in summary.groups[["institution"]]) {
@@ -685,9 +692,7 @@
 
 				if (adj.weights.tf & "WEIGHT" %in% names(tmp.dt.long)) invisible(tmp.dt.long[, WEIGHT := round((WEIGHT / DUP_COUNT), 3)])
 
-				sgp_data_for_summary <- dbConnect(SQLite(), dbname = file.path(tempdir(), "TMP_Summary_Data.sqlite"))
 				dbWriteTable(sgp_data_for_summary, name = "summary_data", overwrite = TRUE, row.names=FALSE, value = tmp.dt.long)
-				dbDisconnect(sgp_data_for_summary)
 
 				rm(tmp.dt.long)
 
@@ -696,9 +701,10 @@
 		} ### End i loop over summary.groups[["institution"]]
 	} ### END j loop over multiple membership groups (if they exist)
 
+    dbDisconnect(sgp_data_for_summary)
+
 	if (!is.null(parallel.config))	stopParallel(parallel.config, par.start)
 
-	unlink(file.path(tempdir(), "TMP_Summary_Data.sqlite"), recursive=TRUE)
 	if ("VALID_CASE_STATUS_ONLY" %in% names(sgp_object@Data)) {
 		sgp_object@Data$VALID_CASE[sgp_object@Data$VALID_CASE_STATUS_ONLY=="VALID_CASE"] <- "INVALID_CASE"
 		setkeyv(sgp_object@Data, getKey(sgp_object))
